Svg constructor

Svg(
  1. PictureInfo pictureInfo, {
  2. double? pixelRatio,
  3. bool fixedRatio = false,
  4. int cacheSize = defaultCacheSize,
})

Creates an Svg with the received pictureInfo. Default pixelRatio is the device pixel ratio. Setting fixedRatio to true ensures the cache uses one entry per rendered size/scale. Default cacheSize is defaultCacheSize, which is 10 as previously; specifying unlimitedCacheSize is the same as using a Map instead of a MemoryCache.