cacheUsage property
int
get
cacheUsage
The number of images currently used by the cache.
Implementation
int get cacheUsage => _imageCache.size;
The number of images currently used by the cache.
int get cacheUsage => _imageCache.size;